<!-- markdownlint-disable MD013 MD043 MD050 -->

# OpenSSA: Neurosymbolic Agentic AI for Industrial Problem-Solving

**Why OpenSSA?**
OpenSSA is an open-source neurosymbolic agentic AI framework
designed to solve complex, high-stakes problems in industries like semiconductor, manufacturing and finance,
where consistency, accuracy and deterministic outcomes are essential.

At the core of OpenSSA is the **Domain-Aware Neurosymbolic Agent (DANA)** architecture,
advancing AI from basic pattern-matching and information retrieval to true problem-solving.
It overcomes the limitations of traditional LLMs and RAG in high-precision, multi-step problem-solving
by combining **Hierarchical Task Plans (HTPs)** to structure complex programs and the **Observe-Orient-Decide-Act Reasoning (OODAR)** paradigm to execute such programs.
By integrating domain-specific knowledge with neural and symbolic planning and reasoning,
OpenSSA consistently delivers accurate solutions for complex industrial challenges.

## Key Benefits of OpenSSA

- **Consistent Results**: Delivers repeatable, high-precision outcomes for complex tasks.
- **Advanced Problem-Solving**: Combines HTPs and OODAR for multi-step planning and reasoning.
- **Scalable Expertise**: Leverages domain knowledge to scale AI without heavy data requirements.
- **Resource Efficiency**: Uses smaller, resource-efficient models, minimizing computational costs.
- **Extensible and Developer-Friendly**: Supports diverse LLM backends and is fully customizable for industry-specific needs.

## Getting Started

- Install with __`pip install openssa`__
_(supports Python 3.12 and 3.13)_

- For the latest capabilities:
__`pip install https://github.com/aitomatic/openssa/archive/main.zip`__.

- Explore the `examples/` directory and developer guides and tutorials on our [documentation site](https://aitomatic.github.io/openssa).

## [API Documentation](https://aitomatic.github.io/openssa/modules)

## Contributing

We welcome contributions from the community!

- Join the discussion on our [Community Forum](https://github.com/aitomatic/openssa/discussions)
- Submit pull requests for bug fixes, enhancements, or new features

For detailed guidelines, refer to our [Contribution Guide](CONTRIBUTING.md).
